@@ -50,11 +50,11 @@ using namespace bpp;
 
 using namespace std;
 
-MafBlock* FeatureExtractor::analyseCurrentBlock_() throw (Exception)
+MafBlock* FeatureExtractorMafIterator::analyseCurrentBlock_() throw (Exception)
 {
   while (blockBuffer_.size() == 0) {
     //Unless there is no more block in the buffer, we need to parse more:
-    auto_ptr<MafBlock> block;
+    unique_ptr<MafBlock> block;
     START:
     block.reset(iterator_->nextBlock());
     if (!block.get()) return 0; //No more block.
@@ -79,13 +79,14 @@ MafBlock* FeatureExtractor::analyseCurrentBlock_() throw (Exception)
       goto START;
 
     //If the reference sequence is on the negative strand, then we have to correct the coordinates:
+    (*logstream_ << "Strand: " << refSeq.getStrand()).endLine();
     if (refSeq.getStrand() == '-') {
       RangeSet<size_t> cRanges;
       for (set<Range<size_t>*>::iterator it = ranges.getSet().begin();
-          it !=  ranges.getSet().end();
+          it != ranges.getSet().end();
           ++it)
       {
-        cRanges.addRange(Range<size_t>(refSeq.getSrcSize() - (**it).end(), refSeq.getSrcSize() - (**it).begin()));
+        cRanges.addRange(SeqRange(refSeq.getSrcSize() - (**it).end(), refSeq.getSrcSize() - (**it).begin(), dynamic_cast<SeqRange*>(*it)->getStrand()));
       }
       ranges = cRanges;
     }
@@ -109,20 +110,24 @@ MafBlock* FeatureExtractor::analyseCurrentBlock_() throw (Exception)
     {
       if (verbose_) {
         ApplicationTools::displayGauge(i++, ranges.getSet().size() - 1, '=');
-      }
+      } 
+      //This does not go after i=0, problem with ranges?????
       MafBlock* newBlock = new MafBlock();
       newBlock->setScore(block->getScore());
       newBlock->setPass(block->getPass());
+      size_t a = walker.getAlignmentPosition((**it).begin() - refSeq.start());
+      size_t b = walker.getAlignmentPosition((**it).end() - refSeq.start() - 1);
       for (size_t j = 0; j < block->getNumberOfSequences(); ++j) {
-        auto_ptr<MafSequence> subseq;
-        size_t a = walker.getAlignmentPosition((**it).begin() - refSeq.start());
-        size_t b = walker.getAlignmentPosition((**it).end() - refSeq.start() - 1);
+        unique_ptr<MafSequence> subseq;
         subseq.reset(block->getSequence(j).subSequence(a, b - a + 1));
         if (!ignoreStrand_) {
-          if (dynamic_cast<SeqRange*>(*it)->isNegativeStrand()) {
+          if ((dynamic_cast<SeqRange*>(*it)->isNegativeStrand() && refSeq.getStrand() == '+') ||
+             (!dynamic_cast<SeqRange*>(*it)->isNegativeStrand() && refSeq.getStrand() == '-'))
+          {
             SequenceTools::invertComplement(*subseq);
           }
         }
+        (*logstream_ << subseq->getName()).endLine();
         newBlock->addSequence(*subseq);
       }
       blockBuffer_.push_back(newBlock);
