@@ -43,6 +43,8 @@ knowledge of the CeCILL license and that you accept its terms.
 #include <Bpp/Text/TextTools.h>
 #include <Bpp/Text/KeyvalTools.h>
 
+#include <algorithm>
+
 using namespace std;
 using namespace bpp;
 
@@ -52,10 +54,13 @@ MafBlock* MafParser::analyseCurrentBlock_() throw (Exception)
 
   string line;
   bool test = true;
-  MafSequence* currentSequence = 0;
+  unique_ptr<MafSequence> currentSequence;
+  
   while (test)
   {
-    if (stream_->eof()) return 0;
+    if (stream_->eof()) {
+     break;
+    }
     getline(*stream_, line, '\n');
     if (TextTools::isEmpty(line))
     {
@@ -64,7 +69,7 @@ MafBlock* MafParser::analyseCurrentBlock_() throw (Exception)
       if (currentSequence) {
         //Add previous sequence:
         block->addSequence(*currentSequence); //The sequence is copied in the container.
-        delete currentSequence;
+        currentSequence.reset();
       }
 
       //end of paragraph
@@ -75,7 +80,7 @@ MafBlock* MafParser::analyseCurrentBlock_() throw (Exception)
       if (currentSequence) {
         //Add previous sequence:
         block->addSequence(*currentSequence); //The sequence is copied in the container.
-        delete currentSequence;
+        currentSequence.reset();
       }
       
       //New block.
@@ -111,17 +116,29 @@ MafBlock* MafParser::analyseCurrentBlock_() throw (Exception)
       if (currentSequence) {
         //Add previous sequence:
         block->addSequence(*currentSequence); //The sequence is copied in the container.
-        delete currentSequence;
+        currentSequence.reset();
+      }
+      string seq = st.nextToken();
+      if (dotOption_ == DOT_ASGAP) {
+        std::replace(seq.begin(), seq.end(), '.', '-');
+      }
+      if (dotOption_ == DOT_ASUNRES) {
+        std::replace(seq.begin(), seq.end(), '.', 'N');
+      }
+      currentSequence.reset(new MafSequence(src, seq, start, strand, srcSize));
+      if (currentSequence->getGenomicSize() != size) {
+        if (checkSequenceSize_)
+          throw Exception("MafAlignmentParser::nextBlock. Sequence found (" + src + ") does not match specified size: " + TextTools::toString(currentSequence->getGenomicSize()) + ", should be " + TextTools::toString(size) + ".");
+        else {
+          if (verbose_) {
+            ApplicationTools::displayWarning("MafAlignmentParser::nextBlock. Sequence found (" + src + ") does not match specified size: " + TextTools::toString(currentSequence->getGenomicSize()) + ", should be " + TextTools::toString(size) + ".");
+          }
+        }
       }
-      const string seq = st.nextToken();
-      currentSequence = new MafSequence(src, seq, start, strand, srcSize);
-      if (currentSequence->getGenomicSize() != size)
-        throw Exception("MafAlignmentParser::nextBlock. Sequence found (" + src + ") does not match specified size: " + TextTools::toString(currentSequence->getGenomicSize()) + ", should be " + TextTools::toString(size) + ".");
-      
       //Add mask:
       if (mask_) {
         vector<bool> mask(currentSequence->size());
-        for (unsigned int i = 0; i < mask.size(); ++i) {
+        for (size_t i = 0; i < mask.size(); ++i) {
           mask[i] = cmAlphabet_.isMasked(seq[i]);
         }
         currentSequence->addAnnotation(new SequenceMask(mask));
@@ -139,7 +156,7 @@ MafBlock* MafParser::analyseCurrentBlock_() throw (Exception)
       string qstr = st.nextToken();
       //Now parse the score string:
       SequenceQuality* seqQual = new SequenceQuality(qstr.size());
-      for (unsigned int i = 0; i < qstr.size(); ++i) {
+      for (size_t i = 0; i < qstr.size(); ++i) {
         char c = qstr[i];
         if (c == '-') {
           seqQual->setScore(i, -1);
@@ -156,6 +173,16 @@ MafBlock* MafParser::analyseCurrentBlock_() throw (Exception)
       currentSequence->addAnnotation(seqQual);
     }
   }
+  //// Final check and passing by results
+
+  //In case last line in not empty:
+  if (currentSequence) {
+    //Add previous sequence:
+    block->addSequence(*currentSequence); //The sequence is copied in the container.
+    currentSequence.reset();
+  }
+  
+  //Returning block:
   return block;
 }
 
