@@ -72,30 +72,34 @@ class MafSequence:
     size_t srcSize_;
 
   public:
-    MafSequence():
-      SequenceWithAnnotation(&AlphabetTools::DNA_ALPHABET), hasCoordinates_(false), begin_(0), species_(""), chromosome_(""), strand_(0), size_(0), srcSize_(0)
-    {
-      size_ = 0;
-    }
+    MafSequence(const Alphabet* alphabet = &AlphabetTools::DNA_ALPHABET):
+      SequenceWithAnnotation(alphabet), hasCoordinates_(false), begin_(0), species_(""), chromosome_(""), strand_(0), size_(0), srcSize_(0)
+    {}
 
-    MafSequence(const std::string& name, const std::string& sequence, bool parseName = true):
-      SequenceWithAnnotation(name, sequence, &AlphabetTools::DNA_ALPHABET), hasCoordinates_(false), begin_(0), species_(""), chromosome_(""), strand_(0), size_(0), srcSize_(0)
+    MafSequence(const std::string& name, const std::string& sequence, bool parseName = true, const Alphabet* alphabet = &AlphabetTools::DNA_ALPHABET):
+      SequenceWithAnnotation(name, sequence, alphabet), hasCoordinates_(false), begin_(0), species_(""), chromosome_(""), strand_(0), size_(0), srcSize_(0)
     {
       size_ = SequenceTools::getNumberOfSites(*this);
       if (parseName)
         splitNameIntoSpeciesAndChromosome(name, species_, chromosome_);
     }
 
-    MafSequence(const std::string& name, const std::string& sequence, size_t begin, char strand, size_t srcSize, bool parseName = true) :
-      SequenceWithAnnotation(name, sequence, &AlphabetTools::DNA_ALPHABET), hasCoordinates_(true), begin_(begin), species_(""), chromosome_(""), strand_(strand), size_(0), srcSize_(srcSize)
+    MafSequence(const std::string& name, const std::string& sequence, size_t begin, char strand, size_t srcSize, bool parseName = true, const Alphabet* alphabet = &AlphabetTools::DNA_ALPHABET) :
+      SequenceWithAnnotation(name, sequence, alphabet), hasCoordinates_(true), begin_(begin), species_(""), chromosome_(""), strand_(strand), size_(0), srcSize_(srcSize)
     {
       size_ = SequenceTools::getNumberOfSites(*this);
       if (parseName)
         splitNameIntoSpeciesAndChromosome(name, species_, chromosome_);
     }
 
-    MafSequence* clone() const { return new MafSequence(*this); }
-
+    MafSequence* clone() const { 
+      return new MafSequence(*this);
+    }
+ 
+    MafSequence* cloneMeta() const { 
+      return new MafSequence(getName(), std::string(), begin_, strand_, srcSize_, true);
+    }
+    
     ~MafSequence() {}
 
   public:
@@ -103,7 +107,7 @@ class MafSequence:
 
     void removeCoordinates() { hasCoordinates_ = false; begin_ = 0; }
 
-    size_t start() const throw (Exception) { 
+    size_t start() const throw (Exception) {
       if (hasCoordinates_) return begin_;
       else throw Exception("MafSequence::start(). Sequence " + getName() + " does not have coordinates.");
     }
@@ -114,11 +118,11 @@ class MafSequence:
     }
 
     /**
-     * @return A range with cooridinates from this sequence.
-     * @param origin Tell if coorinates according to original sequence should be used.
-     * If 'yes' and the sequence is on the negative strand, the returned rang will be computed as [SrcSize-Stop, SrcSize-Start[
+     * @return A range with coordinates from this sequence.
+     * @param origin Tell if coordinates according to original sequence should be used.
+     * If 'yes' and the sequence is on the negative strand, the returned range will be computed as [SrcSize-Stop, SrcSize-Start[
      */
-    Range<size_t> getRange(bool origin=true) const {
+    Range<size_t> getRange(bool origin = true) const {
       if (hasCoordinates_) {
         if (origin && strand_ == '-') {
           return Range<size_t>(srcSize_ - stop(), srcSize_ - start());
