@@ -57,9 +57,22 @@ MafBlock* OutputAlignmentMafIterator::analyseCurrentBlock_() throw (Exception)
     if (output_) {
       writeBlock(*output_, *block);
     } else {
+      string chr   = "ChrNA";
+      string start = "StartNA";
+      string stop  = "StopNA";
+      if (block->hasSequenceForSpecies(refSpecies_)) {
+        const MafSequence& refseq = block->getSequenceForSpecies(refSpecies_);
+        chr   = refseq.getChromosome();
+        start = TextTools::toString(refseq.start());
+        stop  = TextTools::toString(refseq.stop());
+      }
       string file = file_;
       TextTools::replaceAll(file, "%i", TextTools::toString(++currentBlockIndex_));
+      TextTools::replaceAll(file, "%c", chr);
+      TextTools::replaceAll(file, "%b", start);
+      TextTools::replaceAll(file, "%e", stop);
       std::ofstream output(file.c_str(), ios::out);
+
       writeBlock(output, *block);
     }
   }
@@ -69,18 +82,21 @@ MafBlock* OutputAlignmentMafIterator::analyseCurrentBlock_() throw (Exception)
 void OutputAlignmentMafIterator::writeBlock(std::ostream& out, const MafBlock& block) const {
   //First get alignment:
   AlignedSequenceContainer aln(&AlphabetTools::DNA_ALPHABET);
-  //We cannot copy directly the container because we want to convert from MafSequence to BasicSequence (needed for renaiming):
+  //We cannot copy directly the container because we want to convert from MafSequence to BasicSequence (needed for renaming):
   SequenceContainerTools::convertContainer<AlignedSequenceContainer, AlignedSequenceContainer, BasicSequence>(block.getAlignment(), aln);
   //Format sequence names:
   vector<string> names(aln.getNumberOfSequences());
   for (size_t i = 0; i < aln.getNumberOfSequences(); ++i) {
     const MafSequence& mafseq = block.getSequence(i);
-    if (mafseq.hasCoordinates())
+    cout << mafseq.getSpecies() << "\t" << mafseq.getChromosome() << endl;
+    if (mafseq.hasCoordinates() && outputCoordinates_)
       names[i] = mafseq.getSpecies() + "-" + mafseq.getChromosome() + "(" + mafseq.getStrand() + ")/" + TextTools::toString(mafseq.start() + 1) + "-" + TextTools::toString(mafseq.stop() + 1);
     else
       names[i] = mafseq.getSpecies();
   }
   aln.setSequencesNames(names);
+  if (addLDHatHeader_)
+    out << aln.getNumberOfSequences() << " " << aln.getNumberOfSites() << " 1" << endl; //We here assume sequences are haploid.
   writer_->writeAlignment(out, aln);
 }
 
