@@ -63,8 +63,11 @@ class OutputAlignmentMafIterator:
     std::ostream* output_;
     std::string file_;
     bool mask_;
-    std::auto_ptr<OAlignment> writer_;
+    bool outputCoordinates_;
+    bool addLDHatHeader_;
+    std::unique_ptr<OAlignment> writer_;
     unsigned int currentBlockIndex_;
+    std::string refSpecies_;
 
   public:
     /**
@@ -77,9 +80,28 @@ class OutputAlignmentMafIterator:
      * @param writer A pointer toward an alignment writer object which specifies the format to use when writing sequences.
      * The underlying object will be own by this instance, and destroyed when this object is deleted.
      * @param mask Tell if sequences should be printed masked (if applicable).
+     * @param outputCoordinates Tell if coordinates should be written in sequence headers, if any.
+     * @param addLDHatHeader Tell if first line of file should contain number and lenght of sequences (for instance for use with LDhat/convert).
+     * @param reference [optional] specify a reference species which can be used to configure file names
+     * (for instance using coordinates information).
      */
-    OutputAlignmentMafIterator(MafIterator* iterator, std::ostream* out, OAlignment* writer, bool mask = true) :
-      AbstractFilterMafIterator(iterator), output_(out), file_(), mask_(mask), writer_(writer), currentBlockIndex_(0)
+    OutputAlignmentMafIterator(
+        MafIterator* iterator,
+        std::ostream* out,
+        OAlignment* writer,
+        bool mask = true,
+        bool outputCoordinates = true,
+        bool addLDHatHeader = false,
+        const std::string& reference = "") :
+      AbstractFilterMafIterator(iterator),
+      output_(out),
+      file_(),
+      mask_(mask),
+      outputCoordinates_(outputCoordinates),
+      addLDHatHeader_(addLDHatHeader),
+      writer_(writer),
+      currentBlockIndex_(0),
+      refSpecies_(reference)
     {
       if (!writer)
         throw Exception("OutputAlignmentMafIterator (constructor 1): sequence writer should not be a NULL pointer!");
@@ -96,9 +118,28 @@ class OutputAlignmentMafIterator:
      * @param writer A pointer toward an alignment writer object which specifies the format to use when writing sequences.
      * The underlying object will be own by this instance, and destroyed when this object is deleted.
      * @param mask Tell if sequences should be printed masked (if applicable).
+     * @param outputCoordinates Tell if coordinates should be written in sequence headers, if any.
+     * @param addLDHatHeader Tell if first line of file should contain number and lenght of sequences (for instance for use with LDhat/convert).
+     * @param reference [optional] specify a reference species which can be used to configure file names
+     * (for instance using coordinates information).
      */
-    OutputAlignmentMafIterator(MafIterator* iterator, const std::string& file, OAlignment* writer, bool mask = true) :
-      AbstractFilterMafIterator(iterator), output_(0), file_(file), mask_(mask), writer_(writer), currentBlockIndex_(0)
+    OutputAlignmentMafIterator(
+        MafIterator* iterator,
+        const std::string& file,
+        OAlignment* writer,
+        bool mask = true,
+        bool outputCoordinates = true,
+        bool addLDHatHeader = false,
+        const std::string& reference = "") :
+      AbstractFilterMafIterator(iterator),
+      output_(0),
+      file_(file),
+      mask_(mask),
+      outputCoordinates_(outputCoordinates),
+      addLDHatHeader_(addLDHatHeader),
+      writer_(writer),
+      currentBlockIndex_(0),
+      refSpecies_(reference)
     {
       if (!writer)
         throw Exception("OutputAlignmentMafIterator (constructor 2): sequence writer should not be a NULL pointer!");
@@ -112,8 +153,11 @@ class OutputAlignmentMafIterator:
       output_(iterator.output_),
       file_(iterator.file_),
       mask_(iterator.mask_),
+      outputCoordinates_(iterator.outputCoordinates_),
+      addLDHatHeader_(iterator.addLDHatHeader_),
       writer_(),
-      currentBlockIndex_(iterator.currentBlockIndex_)
+      currentBlockIndex_(iterator.currentBlockIndex_),
+      refSpecies_(iterator.refSpecies_)
     {}
     
     OutputAlignmentMafIterator& operator=(const OutputAlignmentMafIterator& iterator)
@@ -121,8 +165,11 @@ class OutputAlignmentMafIterator:
       output_ = iterator.output_;
       file_   = iterator.file_;
       mask_   = iterator.mask_;
+      outputCoordinates_ = iterator.outputCoordinates_;
+      addLDHatHeader_ = iterator.addLDHatHeader_;
       writer_.release();
       currentBlockIndex_ = iterator.currentBlockIndex_;
+      refSpecies_ = iterator.refSpecies_;
       return *this;
     }
 
