@@ -61,6 +61,7 @@ class VcfOutputMafIterator:
     std::ostream* output_;
     std::string refSpecies_;
     std::vector<std::string> genotypes_;
+    bool outputAll_;
 
   public:
     /**
@@ -70,9 +71,10 @@ class VcfOutputMafIterator:
      * @param out The output stream where to write the VCF file.
      * @param reference The species to use as a reference.
      * @param genotypes A list of species for which genotype information should be written in the VCF file. There will be one extra column per genotype, +1 format column.
+     * @param outputAll If true, also output non-variable positions.
      */
-    VcfOutputMafIterator(MafIterator* iterator, std::ostream* out, const std::string& reference, const std::vector<std::string>& genotypes) :
-      AbstractFilterMafIterator(iterator), output_(out), refSpecies_(reference), genotypes_(genotypes)
+    VcfOutputMafIterator(MafIterator* iterator, std::ostream* out, const std::string& reference, const std::vector<std::string>& genotypes, bool outputAll = false) :
+      AbstractFilterMafIterator(iterator), output_(out), refSpecies_(reference), genotypes_(genotypes), outputAll_(outputAll)
     {
       if (output_)
         writeHeader_(*output_);
@@ -83,7 +85,8 @@ class VcfOutputMafIterator:
       AbstractFilterMafIterator(0),
       output_(iterator.output_),
       refSpecies_(iterator.refSpecies_),
-      genotypes_(iterator.genotypes_)
+      genotypes_(iterator.genotypes_),
+      outputAll_(iterator.outputAll_)
     {}
     
     VcfOutputMafIterator& operator=(const VcfOutputMafIterator& iterator)
@@ -91,6 +94,7 @@ class VcfOutputMafIterator:
       output_ = iterator.output_;
       refSpecies_ = iterator.refSpecies_;
       genotypes_ = iterator.genotypes_;
+      outputAll_ = iterator.outputAll_;
       return *this;
     }
 
